import React, { useState, useRef, useEffect } from 'react';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { Icon } from '@highlight-ui/icon';
import { Panel } from '@highlight-ui/panel';
import { Typography } from '@highlight-ui/typography';
import colorTokens from '@highlight-ui/tokens/dist/colors.json';
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
}; // TODO: The values are going to be refactored to use tokens directly instead of SCSS exports


var mainPalette = function (p) {
  return p;
}([{
  identifier: 'support-red-100',
  backgroundColor: colorTokens['support-red-100'],
  highlight: colorTokens['support-red-100']
}, {
  identifier: 'support-pink-100',
  backgroundColor: colorTokens['support-pink-100'],
  highlight: colorTokens['support-pink-100']
}, {
  identifier: 'support-purple-100',
  backgroundColor: colorTokens['support-purple-100'],
  highlight: colorTokens['support-purple-100']
}, {
  identifier: 'support-purple-80',
  backgroundColor: colorTokens['support-purple-80'],
  highlight: colorTokens['support-purple-80']
}, {
  identifier: 'support-dark-blue-100',
  backgroundColor: colorTokens['support-dark-blue-100'],
  highlight: colorTokens['support-dark-blue-100']
}, {
  // TODO: Replace hardcoded color with a color token in DST-2558
  identifier: 'cyan',
  backgroundColor: '#0db5df',
  highlight: '#0db5df'
}, {
  identifier: 'support-green-100',
  backgroundColor: colorTokens['support-green-100'],
  highlight: colorTokens['support-green-100']
}, {
  identifier: 'support-light-green-100',
  backgroundColor: colorTokens['support-light-green-100'],
  highlight: colorTokens['support-light-green-100']
}, {
  identifier: 'support-yellow-100',
  backgroundColor: colorTokens['support-yellow-100'],
  highlight: colorTokens['support-yellow-100']
}, {
  // TODO: Replace hardcoded color with a color token in DST-2558
  identifier: 'orange',
  backgroundColor: '#ffa319',
  highlight: '#ffa319'
}, {
  identifier: 'support-brown-100',
  backgroundColor: colorTokens['support-brown-100'],
  highlight: colorTokens['support-brown-100']
}, {
  identifier: 'support-grey-110',
  backgroundColor: colorTokens['support-grey-110'],
  highlight: colorTokens['support-grey-110']
}]);

var pastelPalette = function (p) {
  return p;
}([{
  identifier: 'support-red-10',
  backgroundColor: colorTokens['support-red-10'],
  highlight: colorTokens['support-red-100']
}, {
  identifier: 'support-pink-10',
  backgroundColor: colorTokens['support-pink-10'],
  highlight: colorTokens['support-pink-100']
}, {
  identifier: 'support-purple-10',
  backgroundColor: colorTokens['support-purple-10'],
  highlight: colorTokens['support-purple-100']
}, {
  // TODO: Replace hardcoded color with a color token in DST-2558
  identifier: 'light-purple',
  backgroundColor: '#e1c5e7',
  highlight: colorTokens['support-purple-80']
}, {
  identifier: 'support-dark-blue-10',
  backgroundColor: colorTokens['support-dark-blue-10'],
  highlight: colorTokens['support-dark-blue-100']
}, {
  // TODO: Replace hardcoded color with a color token in DST-2558
  identifier: 'light-cyan',
  backgroundColor: '#bbe5f8',
  highlight: '#0db5df'
}, {
  identifier: 'support-green-10',
  backgroundColor: colorTokens['support-green-10'],
  highlight: colorTokens['support-green-100']
}, {
  identifier: 'support-light-green-10',
  backgroundColor: colorTokens['support-light-green-10'],
  highlight: colorTokens['support-light-green-100']
}, {
  identifier: 'support-yellow-10',
  backgroundColor: colorTokens['support-yellow-10'],
  highlight: colorTokens['support-yellow-100']
}, {
  // TODO: Replace hardcoded color with a color token in DST-2558
  identifier: 'light-orange',
  backgroundColor: '#fbe1bb',
  highlight: '#ffa319'
}, {
  identifier: 'support-brown-10',
  backgroundColor: colorTokens['support-brown-10'],
  highlight: colorTokens['support-brown-100']
}, {
  identifier: 'support-grey-10',
  backgroundColor: colorTokens['support-grey-10'],
  highlight: colorTokens['support-grey-110']
}]);

var styles = {
  "colorPicker": "ColorPicker-module__3H6ypMLc__v4-1-14",
  "button": "ColorPicker-module__XBQM5x8U__v4-1-14",
  "focus": "ColorPicker-module__1iX9akK___v4-1-14",
  "active": "ColorPicker-module__3K79GJJ5__v4-1-14",
  "disabled": "ColorPicker-module__2PSNxo4E__v4-1-14",
  "buttonArrow": "ColorPicker-module__2AQhgxAG__v4-1-14",
  "colorDot": "ColorPicker-module___ZbovZGW__v4-1-14",
  "panel": "ColorPicker-module__3aVapG4Z__v4-1-14",
  "title": "ColorPicker-module__1dP4IMl5__v4-1-14",
  "colorOptions": "ColorPicker-module__3Ej3KfXm__v4-1-14",
  "colorOption": "ColorPicker-module__19MT-I77__v4-1-14"
};

var ColorPicker = function (_a) {
  var _b = _a.closeOnSelect,
      closeOnSelect = _b === void 0 ? false : _b,
      disabled = _a.disabled,
      initialColor = _a.initialColor,
      metadata = _a.metadata,
      onChange = _a.onChange,
      _c = _a.palette,
      palette = _c === void 0 ? 'main' : _c,
      title = _a.title;

  var _d = useState(false),
      focused = _d[0],
      setFocused = _d[1];

  var wrapperRef = useRef(null);
  var colorPalette = palette === 'pastel' ? pastelPalette : mainPalette;

  var _e = useState(false),
      isPaletteOpen = _e[0],
      setIsPaletteOpen = _e[1];

  var _f = useState(initialColor === undefined ? colorPalette[0].backgroundColor : initialColor),
      currentColor = _f[0],
      setCurrentColor = _f[1];

  useEffect(function () {
    var onDocumentClick = function (e) {
      if (wrapperRef.current && e.target instanceof Node && !wrapperRef.current.contains(e.target)) {
        setIsPaletteOpen(false);
      }
    };

    window.document.addEventListener('mousedown', onDocumentClick);
    return function () {
      window.document.removeEventListener('mousedown', onDocumentClick);
    };
  }, []);

  var getComputedColor = function (cssColorVariable) {
    // Replace var(--support-red-100) with --support-red-100
    var cssVar = cssColorVariable.replace(/(^.*\(|\).*$)/g, '');
    return getComputedStyle(document.documentElement).getPropertyValue(cssVar).trim();
  };

  var onColorClick = function (selectedColor) {
    // TODO: Remove isHexColor check in DST-2558
    var isHexColor = selectedColor.startsWith('#');
    var color = isHexColor ? selectedColor : getComputedColor(selectedColor);
    onChange(color);
    setCurrentColor(selectedColor);

    if (closeOnSelect) {
      setIsPaletteOpen(false);
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: styles.colorPicker,
    ref: wrapperRef
  }, /*#__PURE__*/React.createElement("button", __assign({}, parseMetadata(metadata), {
    className: styles.button,
    disabled: disabled,
    onClick: function () {
      return setIsPaletteOpen(!isPaletteOpen);
    },
    onFocus: function () {
      return setFocused(true);
    },
    onBlur: function () {
      return setFocused(false);
    },
    type: "button"
  }), /*#__PURE__*/React.createElement("div", {
    className: styles.colorDot,
    "data-test-id": "selected-color",
    style: {
      background: currentColor
    }
  }), /*#__PURE__*/React.createElement(Icon, {
    className: styles.buttonArrow,
    name: "sort-down",
    type: "solid",
    color: focused ? 'icon-highlight' : 'icon-subdued'
  })), isPaletteOpen && /*#__PURE__*/React.createElement(Panel, {
    className: styles.panel,
    absolute: true
  }, /*#__PURE__*/React.createElement(Typography, {
    token: "heading-small",
    className: styles.title
  }, title), /*#__PURE__*/React.createElement("div", {
    className: styles.colorOptions
  }, colorPalette.map(function (_a) {
    var identifier = _a.identifier,
        backgroundColor = _a.backgroundColor,
        highlight = _a.highlight;
    return /*#__PURE__*/React.createElement("div", {
      className: styles.colorOption,
      "aria-label": "select-color-" + identifier,
      key: identifier,
      onClick: function () {
        return onColorClick(backgroundColor);
      },
      onKeyDown: function (e) {
        return e.key === 'Enter' && onColorClick(backgroundColor);
      },
      role: "button",
      style: {
        backgroundColor: backgroundColor,
        color: highlight
      },
      tabIndex: 0
    });
  }))));
};

export { ColorPicker };
//# sourceMappingURL=index.js.map
